@@ -5,7 +5,7 @@ from nupropagator.cross_section import cross_ground as cg
 #from cross_section import cross_ground as cg
 from nudisxs.disxs import *
 from scipy.spatial.transform import Rotation as R
-
+from nudisxs.integrand_2d import*
 class NuGen:
     def __init__(self):
         self.nu_energy_GeV = 0.
@@ -102,18 +102,18 @@ class NuGen:
 
     def get_xy_Bjorken_old(self,mode):
         x=y=-1.0 # impossible values
-        self.dis.init_current(current[mode])
+        self.dis.init_current(self.current[mode])
         
         def get_random(x,y,crossing,diff_xsec_xy):
             c =  crossing(self.nu_energy_GeV)*np.random.random()
             xsec = diff_xsec_xy(self.nu_energy_GeV,x,y)
             if(c-xsec >= 0): 
-              return true 
+              return True 
 
         while(True):
             x = np.random.random()
             y = np.random.random()
-            if get_random(x,y,self.cross[(self.current,self.target)],self.xsec_xy[self.current]):
+            if get_random(x,y,self.cross_ground[(mode,self.target)],self.xsec_xy[mode]):
                break 
         return x,y
 
@@ -121,9 +121,9 @@ class NuGen:
         x = []
         y = []
         weight = []
-        integ = inregrand_2dxy()
+        integ = integrand_2dxy()
         integ.dis.init_neutrino(self.nu_pdg)
-        integ.dis.current(self.current)
+        integ.dis.init_current(self.current[mode])
         integ.dis.init_target(self.target)
         integ.calculate(self.nu_energy_GeV)
         for Bj,wgt in integ.integrator.random():
@@ -188,7 +188,7 @@ class NuGen:
         nu_energy = self.get_neutrino_energy()
         self.get_target()
         mode = self.get_current()
-        x,y,weight = self.get_xy_Bjorken_fix_en(mode)
+        x,y,weight = self.get_xy_Bjorken_new(mode)
         return self.get_particles_momenta(x, y, nu_cos, nu_sin, nu_phi)
 
     def next(self):
